# The Number Game

This Python module allows you to guess random numbers within your selected
number of attempts. It also allows you to guess Prime numbers within your
selected number of attempts.

## Instructions
- Enter your terminal

- Install the module:
    - ```pip install nummer```

- Enter your python interactive shell:
    - ```python```

- Import required functions:
    - ```from nummer import Classify, Prime```

- Iterate through attempts by guessing random numbers:
    - ```Classify(n).guess_number()```

- Iterate through attempts by guessing prime numbers:
    - ```Prime(n).guess_prime_number()```

- Note:
    - n represents the number of attempts

- Illustration
    - You can look into the screenshots below to follow through the process of
      guessing random numbers and prime numbers in three attempts.

    - ![Random numbers](https://github.com/imisi-akande/number-game/blob/styles%2Fadd-extra-files/images/guess_number.png)

    - ![Prime numbers](https://github.com/imisi-akande/number-game/blob/styles/add-extra-files/images/guess_prime_numbers.png)

Have fun. Please Feel free to contact me if you encounter any issue.